package com.biganto.visual.roompark.presentation.screen.feed_list

import android.view.View
import androidx.core.os.bundleOf
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import butterknife.BindView
import com.biganto.visual.roompark.R
import com.biganto.visual.roompark.base.RoomParkApplication
import com.biganto.visual.roompark.base.RoomParkMainActivity
import com.biganto.visual.roompark.conductor.BigantoBaseController
import com.biganto.visual.roompark.presentation.screen.feed_list.util.ArticlesAdapter
import com.biganto.visual.roompark.util.view_utils.grid.CeilsDecoration
import timber.log.Timber
import javax.inject.Inject

/**
 * Created by Vladislav Bogdashkin on 30.09.2019.
 */

private const val FEED_ID = "DIRECT_FEED_ID_KEY"

class ArticlesScreenController  :
    BigantoBaseController<ArticlesScreenViewState
        , ArticlesScreen
        , ArticlesScreenPresenter>
    , ArticlesScreen {


    constructor()

    constructor(feedId:Int):super(bundleOf(FEED_ID to feedId))

    override fun injectDependencies() {
        getComponent()
    }

    @Inject
    override lateinit var injectedPresenter: ArticlesScreenPresenter

    @BindView(R.id.articles_recycler_view)
    lateinit var articlesRecyclerView: RecyclerView


    private fun setToolbar(){
        toolBar.showAll()
        toolBar.appBar.setExpanded(false,false)
        toolBar.collapsingToolbarLayout.title = "ИЗБРАННОЕ"
        toolBar.appBar.setLiftable(true)
        toolBar.appBarScrollable(false)
        articlesRecyclerView.isNestedScrollingEnabled = false
    }

    private fun bindRecycler() {
        articlesRecyclerView.isNestedScrollingEnabled = true
        articlesRecyclerView.layoutManager =
            LinearLayoutManager(activity, RecyclerView.VERTICAL, false)
        articlesRecyclerView.adapter = ArticlesAdapter()
        articlesRecyclerView.itemAnimator = null

        if (articlesRecyclerView.itemDecorationCount == 0)
            articlesRecyclerView.addItemDecoration(
                CeilsDecoration(1
                , resources?.getDimensionPixelSize(R.dimen.ceil_grid_padding))
            )
    }

    override fun onViewBound(v: View) {
//        setToolbar()
        bindRecycler()
    }

    override fun render(viewState: ArticlesScreenViewState) {
        super.render(viewState)
        Timber.d("Render state $viewState")
        when(viewState){
            is ArticlesScreenViewState.Idle -> render(viewState)
            is ArticlesScreenViewState.ArticlesLoaded -> render(viewState)
        }
    }

    private fun render(viewState: ArticlesScreenViewState.Idle){

    }


    private fun render(viewState: ArticlesScreenViewState.ArticlesLoaded) {
        (articlesRecyclerView.adapter as ArticlesAdapter).setItems(viewState.items)
    }

    private fun getComponent() = DaggerArticlesScreenComponent.factory()
        .create(2,RoomParkApplication.component,activity as RoomParkMainActivity)
        .inject(this)

    override fun getLayoutId(): Int = R.layout.feeds_screen


}