package com.biganto.visual.roompark.presentation.screen.feed_list

import com.biganto.visual.roompark.conductor.BigantoBasePresenter
import com.biganto.visual.roompark.domain.interactor.ArticlesInteractor
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.schedulers.Schedulers
import timber.log.Timber
import javax.inject.Inject
import javax.inject.Named

/**
 * Created by Vladislav Bogdashkin on 30.09.2019.
 */


class ArticlesScreenPresenter @Inject constructor(
    @Named("FEED_ID_INT") private val feedId:Int,
    private val interactor: ArticlesInteractor
)
    : BigantoBasePresenter<ArticlesScreen, ArticlesScreenViewState>() {


    override fun bindIntents() {
        Timber.d("feedId : $feedId")

        val prefetchCards = interactor.fetchArticles(1)
            .map { ArticlesScreenViewState.ArticlesLoaded(it.articles) }

        val state = restoreStateObservable
            .mergeWith(prefetchCards)
            .doOnError{ Timber.e(it)}
            .subscribeOn(Schedulers.io())
            .observeOn(AndroidSchedulers.mainThread())

        subscribeViewState(state.cast(ArticlesScreenViewState::class.java), ArticlesScreen::render)
    }

}