package com.biganto.visual.roompark.presentation.screen.feeds

import com.biganto.visual.roompark.conductor.BigantoBasePresenter
import com.biganto.visual.roompark.domain.interactor.FeedsInteractor
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.schedulers.Schedulers
import timber.log.Timber
import javax.inject.Inject

/**
 * Created by Vladislav Bogdashkin on 30.09.2019.
 */


class FeedsScreenPresenter @Inject constructor(
    private val interactor: FeedsInteractor
)
    : BigantoBasePresenter<FeedsScreen, FeedsScreenViewState>() {


    override fun bindIntents() {

        val fetchCams = interactor.fetchCams()
            .map {FeedsScreenViewState.CamsList(it.items) }

        val fetchAlbums = interactor.fetchAlbums()
            .map {FeedsScreenViewState.AlbumsPages(it) }

        val fetchFeeds = interactor.fetchTopFeeds()
            .map {FeedsScreenViewState.FeedsPages(it.feeds.toList()) }

        val  getFeedArticlesPreview = intent(FeedsScreen::feedsTabSelected)
            .flatMapSingle { interactor.fetchArticles(it) }
            .map { FeedsScreenViewState.GetFeedArticlesPreview(it.articles.toList()) }

        val state = restoreStateObservable
            .mergeWith(fetchFeeds)
            .mergeWith(getFeedArticlesPreview)
            .mergeWith(fetchAlbums)
            .mergeWith(fetchCams)
            .doOnError{ Timber.e(it)}
            .subscribeOn(Schedulers.io())
            .observeOn(AndroidSchedulers.mainThread())

        subscribeViewState(state.cast(FeedsScreenViewState::class.java), FeedsScreen::render)
    }

}