package com.biganto.visual.roompark.presentation.screen.feeds.utils

import android.view.View
import android.widget.ImageView
import android.widget.TextView
import butterknife.BindView
import com.biganto.visual.roompark.R
import com.biganto.visual.roompark.domain.model.ArticlePreviewModel
import com.biganto.visual.roompark.presentation.screen.settings.util.CommonRecyclerAdapter
import com.biganto.visual.roompark.presentation.screen.settings.util.CommonViewHolder
import com.squareup.picasso.Picasso
import java.text.SimpleDateFormat
import java.util.*


/**
 * Created by Vladislav Bogdashkin on 15.10.2019.
 */
class ArticlesPreviewAdapter : CommonRecyclerAdapter<ArticlePreviewViewHolder,ArticlePreviewModel>() {
    override val vhKlazz = ArticlePreviewViewHolder::class

    override fun getVhLayout(): Int = R.layout.feed_preview_viewholder
}




class ArticlePreviewViewHolder(itemView: View) : CommonViewHolder<ArticlePreviewModel>(itemView) {

    private val dateFormatter = SimpleDateFormat("dd / MM / yyyy", Locale.getDefault())

    @BindView(R.id.imageHolder) lateinit var preview:ImageView
    @BindView(R.id.feed_date_text_view) lateinit var articleDate:TextView
    @BindView(R.id.feed_title_info_text_view) lateinit var articleTitle:TextView
    @BindView(R.id.feed_read) lateinit var articleIsRead:View

    override fun onViewBound(model: ArticlePreviewModel) {
        articleDate.text = dateFormatter.format(model.published)
        articleTitle.text = model.title
        articleIsRead.setGone(model.isRead)

        Picasso.get()
            .load(model.previewUrl)
            .into(preview)
    }
}

private fun View.setGone(isGone:Boolean){
    this.visibility = if (isGone) View.GONE else View.VISIBLE
}